# LTP305 - Breakout Garden dual 5x7 LED matrix driver

[![Build Status](https://travis-ci.com/pimoroni/ltp305-python.svg?branch=master)](https://travis-ci.com/pimoroni/ltp305-python)
[![Coverage Status](https://coveralls.io/repos/github/pimoroni/ltp305-python/badge.svg?branch=master)](https://coveralls.io/github/pimoroni/ltp305-python?branch=master)
[![PyPi Package](https://img.shields.io/pypi/v/ltp305.svg)](https://pypi.python.org/pypi/ltp305)
[![Python Versions](https://img.shields.io/pypi/pyversions/ltp305.svg)](https://pypi.python.org/pypi/ltp305)

# Pre-requisites

You must enable i2c:

* i2c: `sudo raspi-config nonint do_i2c 0`

You can optionally run `sudo raspi-config` or the graphical Raspberry Pi Configuration UI to enable interfaces.

# Installing

Stable library from PyPi:

* Just run `sudo pip3 install ltp305`

Latest/development library from GitHub:

* `git clone https://github.com/pimoroni/ltp305-python`
* `cd ltp305-python`
* `sudo ./install.sh`


# Changelog
0.0.1
-----

* Initial Release
